@@ -8,6 +8,7 @@
 
 #include <QStandardPaths>
 
+#include <KX11Extras>
 #include <QDebug>
 #include <QGuiApplication>
 #include <QScreen>
@@ -85,7 +86,14 @@ bool FullScreenOverlay::event(QEvent *e)
             m_plasmaShellSurface->setSkipTaskbar(true);
         }
     } else if (e->type() == QEvent::Expose) {
-        KWindowSystem::setState(winId(), NET::SkipTaskbar | NET::SkipPager);
+        if (KWindowSystem::isPlatformX11()) {
+            KX11Extras::setState(winId(), NET::SkipTaskbar | NET::SkipPager);
+        } else {
+            if (m_plasmaShellSurface) {
+                m_plasmaShellSurface->setSkipTaskbar(true);
+                m_plasmaShellSurface->setSkipSwitcher(true);
+            }
+        }
     }
 
     return QQuickWindow::event(e);
